@@ -490,10 +490,9 @@ class ExceptionWriter():
             self.config.syntax_error_color
         """
 
-        line = str(line)
         lines = []
         if filepath == '<stdin>':
-            lines.append(line.rstrip())
+            lines.append(str(line).rstrip())
             line = target_line = start = end = 0
         else:
             if is_final:
